@@ -80,6 +80,8 @@
   #define EIGEN_HAS_MM_MALLOC 0
 #endif
 
+namespace Eigen {
+
 namespace internal {
 
 inline void throw_std_bad_alloc()
@@ -504,8 +506,6 @@ template<typename T> struct smart_copy_helper<T,false> {
 };
 
 
-} // end namespace internal
-
 /*****************************************************************************
 *** Implementation of runtime stack allocation (falling back to malloc)    ***
 *****************************************************************************/
@@ -520,8 +520,6 @@ template<typename T> struct smart_copy_helper<T,false> {
   #endif
 #endif
 
-namespace internal {
-
 // This helper class construct the allocated memory, and takes care of destructing and freeing the handled data
 // at destruction time. In practice this helper class is mainly useful to avoid memory leak in case of exceptions.
 template<typename T> class aligned_stack_memory_handler
@@ -552,7 +550,7 @@ template<typename T> class aligned_stack_memory_handler
     bool m_deallocate;
 };
 
-}
+} // end namespace internal
 
 /** \internal
   * Declares, allocates and construct an aligned buffer named NAME of SIZE elements of type TYPE on the stack
@@ -722,6 +720,15 @@ public:
         ::new( p ) T( value );
     }
 
+    // Support for c++11
+#if (__cplusplus >= 201103L)
+    template<typename... Args>
+    void  construct(pointer p, Args&&... args)
+    {
+      ::new(p) T(std::forward<Args>(args)...);
+    }
+#endif
+
     void destroy( pointer p )
     {
         p->~T();
@@ -955,4 +962,6 @@ inline int queryTopLevelCacheSize()
 
 } // end namespace internal
 
+} // end namespace Eigen
+
 #endif // EIGEN_MEMORY_H
