@@ -26,9 +26,10 @@
 #ifndef EIGEN_EIGENSOLVER_H
 #define EIGEN_EIGENSOLVER_H
 
-#include "./EigenvaluesCommon.h"
 #include "./RealSchur.h"
 
+namespace Eigen { 
+
 /** \eigenvalues_module \ingroup Eigenvalues_Module
   *
   *
@@ -588,4 +589,6 @@ void EigenSolver<MatrixType>::doComputeEigenvectors()
   }
 }
 
+} // end namespace Eigen
+
 #endif // EIGEN_EIGENSOLVER_H
