@@ -25,6 +25,8 @@
 #ifndef EIGEN_RANDOMSETTER_H
 #define EIGEN_RANDOMSETTER_H
 
+namespace Eigen { 
+
 /** Represents a std::map
   *
   * \see RandomSetter
@@ -335,4 +337,6 @@ class RandomSetter
     unsigned char m_keyBitsOffset;
 };
 
+} // end namespace Eigen
+
 #endif // EIGEN_RANDOMSETTER_H
